aboutsummaryrefslogtreecommitdiff
path: root/src/QXmppIncomingClient.cpp
diff options
context:
space:
mode:
authorJeremy Lainé <jeremy.laine@m4x.org>2010-08-23 07:55:15 +0000
committerJeremy Lainé <jeremy.laine@m4x.org>2010-08-23 07:55:15 +0000
commitc02547eff8d35d8cbee7869329820dc582cc3949 (patch)
treed260690c39cd5721e42a5fb63221c3253defd7d9 /src/QXmppIncomingClient.cpp
parentccb60b7970adeb4d11a02d41cecb607e331ef52e (diff)
downloadqxmpp-c02547eff8d35d8cbee7869329820dc582cc3949.tar.gz
add isConnected() methods to all streams
Diffstat (limited to 'src/QXmppIncomingClient.cpp')
-rw-r--r--src/QXmppIncomingClient.cpp8
1 files changed, 6 insertions, 2 deletions
diff --git a/src/QXmppIncomingClient.cpp b/src/QXmppIncomingClient.cpp
index dcfe26f0..565a17c9 100644
--- a/src/QXmppIncomingClient.cpp
+++ b/src/QXmppIncomingClient.cpp
@@ -71,6 +71,7 @@ QXmppIncomingClient::QXmppIncomingClient(QSslSocket *socket, const QString &doma
bool check = connect(d->idleTimer, SIGNAL(timeout()),
this, SLOT(slotTimeout()));
Q_ASSERT(check);
+ Q_UNUSED(check);
}
/// Destroys the current stream.
@@ -81,12 +82,15 @@ QXmppIncomingClient::~QXmppIncomingClient()
delete d;
}
/// Returns true if the client is authenticated and a resource is bound.
///
bool QXmppIncomingClient::isConnected() const
{
- return !d->username.isEmpty() && !d->resource.isEmpty();
+ return QXmppStream::isConnected() &&
+ !d->username.isEmpty() &&
+ !d->resource.isEmpty();
}
/// Returns the client's JID.
@@ -81,12 +82,15 @@ QXmppIncomingClient::~QXmppIncomingClient()
delete d;
}
-/// Returns true if the client is authenticated and a resource is bound.
+/// Returns true if the socket is connected, the client is authenticated
+/// and a resource is bound.
///
bool QXmppIncomingClient::isConnected() const